//     ____   ______ __
//    / __ \ / ____// /
//   / /_/ // /    / /
//  / ____// /___ / /___   PixInsight Class Library
// /_/     \____//_____/   PCL 2.4.23
// ----------------------------------------------------------------------------
// pcl/Label.h - Released 2022-03-12T18:59:29Z
// ----------------------------------------------------------------------------
// This file is part of the PixInsight Class Library (PCL).
// PCL is a multiplatform C++ framework for development of PixInsight modules.
//
// Copyright (c) 2003-2022 Pleiades Astrophoto S.L. All Rights Reserved.
//
// Redistribution and use in both source and binary forms, with or without
// modification, is permitted provided that the following conditions are met:
//
// 1. All redistributions of source code must retain the above copyright
//    notice, this list of conditions and the following disclaimer.
//
// 2. All redistributions in binary form must reproduce the above copyright
//    notice, this list of conditions and the following disclaimer in the
//    documentation and/or other materials provided with the distribution.
//
// 3. Neither the names "PixInsight" and "Pleiades Astrophoto", nor the names
//    of their contributors, may be used to endorse or promote products derived
//    from this software without specific prior written permission. For written
//    permission, please contact info@pixinsight.com.
//
// 4. All products derived from this software, in any form whatsoever, must
//    reproduce the following acknowledgment in the end-user documentation
//    and/or other materials provided with the product:
//
//    "This product is based on software from the PixInsight project, developed
//    by Pleiades Astrophoto and its contributors (https://pixinsight.com/)."
//
//    Alternatively, if that is where third-party acknowledgments normally
//    appear, this acknowledgment must be reproduced in the product itself.
//
// THIS SOFTWARE IS PROVIDED BY PLEIADES ASTROPHOTO AND ITS CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
// TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
// PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL PLEIADES ASTROPHOTO OR ITS
// CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
// EXEMPLARY OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, BUSINESS
// INTERRUPTION; PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; AND LOSS OF USE,
// DATA OR PROFITS) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.
// ----------------------------------------------------------------------------

#ifndef __PCL_Label_h
#define __PCL_Label_h

/// \file pcl/Label.h

#ifndef __PCL_BUILDING_PIXINSIGHT_APPLICATION

#include <pcl/Defs.h>

#include <pcl/Frame.h>
#include <pcl/TextAlign.h>

namespace pcl
{

// ----------------------------------------------------------------------------

/*!
 * \class Label
 * \brief Client-side interface to a PixInsight %Label control.
 *
 * ### TODO: Write a detailed description for %Label.
 */
class PCL_CLASS Label : public Frame
{
public:

   /*!
    * Constructs a %Label object with the specified \a text, as a child control
    * of \a parent.
    */
   Label( const String& text = String(), Control& parent = Control::Null() );

   /*!
    * Destroys a %Label object.
    */
   virtual ~Label()
   {
   }

   /*! #
    */
   String Text() const;

   /*! #
    */
   void SetText( const String& );

   /*! #
    */
   void Clear()
   {
      SetText( String() );
   }

   /*! #
    */
   int Margin() const;

   /*! #
    */
   void SetMargin( int );

   /*! #
    */
   void ClearMargin()
   {
      SetMargin( 0 );
   }

   /*! #
    */
   int TextAlignment() const;

   /*! #
    */
   void SetTextAlignment( int );

   /*! #
    */
   bool IsWordWrappingEnabled() const;

   /*! #
    */
   void EnableWordWrapping( bool = true );

   /*! #
    */
   void DisableWordWrapping( bool disable = true )
   {
      EnableWordWrapping( !disable );
   }

   /*! #
    */
   bool IsRichTextEnabled() const;

   /*! #
    */
   void EnableRichText( bool = true );

   /*! #
    */
   void DisableRichText( bool disable = true )
   {
      EnableRichText( !disable );
   }
};

// ----------------------------------------------------------------------------

} // pcl

#endif   // __PCL_BUILDING_PIXINSIGHT_APPLICATION

#endif   // __PCL_Label_h

// ----------------------------------------------------------------------------
// EOF pcl/Label.h - Released 2022-03-12T18:59:29Z
